@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
-our $DATE = '2016-06-23'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -251,7 +251,7 @@ sub list_bencher_results {
           QUERY_WORD:
             for my $q (@{ $args{query} }) {
                 my $lq = lc($q);
-                if (index(lc($row->{cpu}), $lq) == -1 &&
+                if (index(lc($row->{cpu} // ''), $lq) == -1 &&
                         index(lc($row->{filename}), $lq) == -1 &&
                         index(lc($row->{scenario}), $lq) == -1
                 ) {
@@ -290,7 +290,7 @@ sub list_bencher_results {
         $resmeta->{'cmdline.skip_format'} = 1;
         my @content;
         for my $row (@rows) {
-            push @content, "$row->{filename} (cpu: $row->{cpu}):\n";
+            push @content, "$row->{filename} (cpu: ", ($row->{cpu}//''), "):\n";
             push @content, Bencher::Backend::format_result($row->{res});
             push @content, "\n";
         }
@@ -428,7 +428,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.14 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-06-23.
+This document describes version 0.15 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
